(getting-started)=
# Getting started

The aim of this section is to get you started with aiida-vasp. We will guide you through the installation process, configure for your VASP executable, and run a simple calculation.

```{toctree}
./installation.md
./configuration.md
./simple_calculation.md
```
